@@ -32,7 +32,12 @@ from copy import copy as pcopy
 from datetime import datetime
 from sys import modules
 from threading import Thread
-from Queue import Queue
+
+# Needed for both pip2 and pip3 to be supported
+try:
+    from Queue import Queue
+except ImportError:
+    from queue import Queue
 
 import pygrametl
 from pygrametl.FIFODict import FIFODict
@@ -41,7 +46,7 @@ from pygrametl.FIFODict import FIFODict
 
 __author__ = "Christian Thomsen"
 __maintainer__ = "Christian Thomsen"
-__version__ = '2.2'
+__version__ = '2.3'
 __all__ = ['JDBCConnectionWrapper', 'BackgroundJDBCConnectionWrapper']
 
 
@@ -66,9 +71,9 @@ class JDBCConnectionWrapper(object):
              open. Default: 20.
         """
         if not isinstance(jdbcconn, jdbc.Connection):
-            raise TypeError, '1st argument must implement java.sql.Connection'
+            raise TypeError('1st argument must implement java.sql.Connection')
         if jdbcconn.isClosed():
-            raise ValueError, '1st argument must be an open Connection'
+            raise ValueError('1st argument must be an open Connection')
         self.__jdbcconn = jdbcconn
         # Add a finalizer to __prepstmts to close PreparedStatements when
         # they are pushed out
@@ -282,7 +287,7 @@ class JDBCConnectionWrapper(object):
 
     def cursor(self):
         """Not implemented for this JDBC connection wrapper!"""
-        raise NotImplementedError, ".cursor() not supported"
+        raise NotImplementedError(".cursor() not supported")
 
     def resultnames(self):
         if self.__resultnames is None:
@@ -548,7 +553,7 @@ class BackgroundJDBCConnectionWrapper(object):
 
     def cursor(self):
         """Not implemented for this JDBC connection wrapper!"""
-        raise NotImplementedError, ".cursor() not supported"
+        raise NotImplementedError(".cursor() not supported")
 
     def resultnames(self):
         self.__queue.join()
