@@ -33,8 +33,13 @@
 
 import copy
 import os
-from Queue import Empty
+try:
+    from Queue import Empty # Python 2
+except ImportError:
+    from queue import Empty # Python 3
+
 import sys
+from sys import version_info
 if sys.platform.startswith('java'):
     # Jython specific code in jythonmultiprocessing
     import pygrametl.jythonmultiprocessing as multiprocessing
@@ -42,11 +47,17 @@ else:
     # Use (C)Python's std. lib.
     import multiprocessing
 
+# Jython 2.5.X specific code
+try:
+    next
+except NameError:
+    from pygrametl import next
+
 import pygrametl
 
 __author__ = "Christian Thomsen"
 __maintainer__ = "Christian Thomsen"
-__version__ = '2.2'
+__version__ = '2.3'
 __all__ = ['splitpoint', 'endsplits', 'createflow', 'Decoupled',
            'shareconnectionwrapper', 'getsharedsequencefactory']
 
@@ -207,8 +218,8 @@ def splitpoint(*arg, **kwargs):
 
     for kw in kwargs.keys():
         if kw not in ('instances', 'output', 'queuesize'):
-            raise TypeError, \
-                "'%s' is an invalid keyword argument for splitpoint" % kw
+            raise TypeError(\
+                "'%s' is an invalid keyword argument for splitpoint" % kw)
 
     output = kwargs.get('output', None)
     instances = kwargs.get('instances', 1)
@@ -242,7 +253,7 @@ def splitpoint(*arg, **kwargs):
     elif len(arg) == 1:
         return decorator(*arg)
     else:
-        raise ValueError, 'More than one *arg given'
+        raise ValueError('More than one *arg given')
 
 
 def endsplits():
@@ -348,7 +359,7 @@ class Flow(object):
                     retryingafterclose = True
                     continue
                 else:
-                    raise Empty
+                    raise Empty()
 
     def getall(self):
         """Return all results in a single list. 
@@ -458,12 +469,12 @@ def createflow(*functions, **options):
         else:
             # Check the arguments
             if not hasattr(item, '__iter__'):
-                raise ValueError, \
-                    'An element is neither iterable nor callable'
+                raise ValueError(\
+                    'An element is neither iterable nor callable')
             for f in item:
                 if not callable(f):
-                    raise ValueError, \
-                        'An element in a sequence is not callable'
+                    raise ValueError(\
+                        'An element in a sequence is not callable')
             # We can - finally - create the function
             groupfunc = _buildgroupfunction(item)
             resultfuncs.append(groupfunc)
@@ -613,7 +624,7 @@ class Decoupled(object):
                 fut = args[x][y][z]
                 args[x][y][z] = self.__getresultfromother(fut.creator, fut.id)
             else:
-                raise ValueError, 'Positions must be of length 2 or 3'
+                raise ValueError('Positions must be of length 2 or 3')
 
     def __decoupledworker(self):
         sys.excepthook = _getexcepthook()
@@ -678,9 +689,9 @@ class Decoupled(object):
 
     def _getresult(self, future):
         if self.__fromworker is None:
-            raise RuntimeError, "Return values are not kept"
+            raise RuntimeError("Return values are not kept")
         if future.creator != self.__instancenumber:
-            raise ValueError, "Cannot return results from other instances"
+            raise ValueError("Cannot return results from other instances")
         # else find and return the result
         while True:
             if future.id in self.__results:
@@ -818,14 +829,22 @@ class SharedConnectionWrapperClient(object):
         for r in rows:
             yield dict(zip(names, r))
 
+    def __fetchonehelper(self):
+        # returns (rownames, tuple with values) where the latter tuple might
+        # contain only None values. Dimension.lookup expects a tuple.
+        (rownames, row) = self.__getrows(1)
+        if not row:
+            row = (None, ) * len(rownames)
+        return (rownames, row)
+
     def fetchone(self, names=None):
         """Return one result row (i.e. dict)."""
-        (rownames, row) = self.__getrows(1)
+        (rownames, row) = self.__fetchonehelper()
         return dict(zip(names or rownames, row))
 
     def fetchonetuple(self):
         """Return one result tuple."""
-        (rownames, row) = self.__getrows(1)
+        (ignoredrownames, row) = self.__fetchonehelper()
         return row
 
     def fetchmanytuples(self, cnt):
@@ -867,7 +886,7 @@ class SharedConnectionWrapperClient(object):
 
     def cursor(self):
         """Return a cursor object. Optional method."""
-        raise NotImplementedError
+        raise NotImplementedError()
 
     def resultnames(self):
         (rownames, nothing) = self.__getrows(None)
@@ -995,13 +1014,23 @@ def shareconnectionwrapper(targetconnection, maxclients=10, userfuncs=()):
                                              toclients)
     userfuncnames = []
     for func in userfuncs:
-        if not (callable(func) and hasattr(func, 'func_name') and \
-                    not func.func_name == '<lambda>'):
-            raise ValueError, "Elements in userfunc must be callable and named"
-        if hasattr(SharedConnectionWrapperClient, func.func_name):
-            raise ValueError, "Illegal function name: " + func.func_name
-        setattr(serverCW, '_userfunc_' + func.func_name, func)
-        userfuncnames.append(func.func_name)
+        # Compatability for Python 2 and 3
+        if version_info[0] == 2:
+            if not (callable(func) and hasattr(func, 'func_name') and \
+                        not func.func_name == '<lambda>'):
+                raise ValueError("Elements in userfunc must be callable and named")
+            if hasattr(SharedConnectionWrapperClient, func.func_name):
+                raise ValueError("Illegal function name: " + func.func_name)
+            setattr(serverCW, '_userfunc_' + func.func_name, func)
+            userfuncnames.append(func.func_name)
+        else:
+            if not (callable(func) and hasattr(func, '__name__') and \
+                        not func.__name__ == '<lambda>'):
+                raise ValueError("Elements in userfunc must be callable and named")
+            if hasattr(SharedConnectionWrapperClient, func.__name__):
+                raise ValueError("Illegal function name: " + func.__name__)
+            setattr(serverCW, '_userfunc_' + func.__name__, func)
+            userfuncnames.append(func.__name__)
     serverprocess = multiprocessing.Process(target=serverCW.worker)
     serverprocess.name = 'Process for shared connection wrapper'
     serverprocess.daemon = True
@@ -1065,7 +1094,7 @@ def getsharedsequencefactory(startvalue, intervallen=5000):
         generator = valuedeliverer() # get a unique generator
         # The method called (i.e., the g) by the end-consumer
         def getnextseqval(*ignored):
-            return generator.next()
+            return next(generator)
         return getnextseqval
 
     return factory
